@@ -68,6 +68,10 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   friend class Singleton<PhoneNumberUtil>;
 
  public:
+  // This type is neither copyable nor movable.
+  PhoneNumberUtil(const PhoneNumberUtil&) = delete;
+  PhoneNumberUtil& operator=(const PhoneNumberUtil&) = delete;
+
   ~PhoneNumberUtil();
   static const char kRegionCodeForNonGeoEntity[];
 
@@ -958,16 +962,21 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
                         bool check_region,
                         PhoneNumber* phone_number) const;
 
-  void BuildNationalNumberForParsing(const string& number_to_parse,
-                                     string* national_number) const;
+  absl::optional<string> ExtractPhoneContext(
+      const string& number_to_extract_from,
+      size_t index_of_phone_context) const;
+
+  bool IsPhoneContextValid(absl::optional<string> phone_context) const;
+
+  ErrorType BuildNationalNumberForParsing(const string& number_to_parse,
+                                          string* national_number) const;
 
   bool IsShorterThanPossibleNormalNumber(const PhoneMetadata* country_metadata,
                                          const string& number) const;
 
-  DISALLOW_COPY_AND_ASSIGN(PhoneNumberUtil);
 };
 
 }  // namespace phonenumbers
 }  // namespace i18n
 
-#endif  // I18N_PHONENUMBERS_PHONENUMBERUTIL_H_
+#endif  // I18N_PHONENUMBERS_PHONENUMBERUTIL_H_
\ No newline at end of file
