@@ -23,10 +23,6 @@ import com.google.phonenumbers.demo.template.InputFormTemplates.InputForm;
 
 public class InputFormRenderer extends LibPhoneNumberRenderer<InputForm> {
 
-  public InputFormRenderer() {
-    super("input_form.soy", "com.google.phonenumbers.demo.inputForm");
-  }
-
   @Override
   public String genHtml() {
     return super.render(
